@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import sys
 import argparse
 import uuid
 import json
@@ -98,7 +99,10 @@ def main():
     app.logger.info("* Running gourd_http on http://%s:%s, gourd is %s:%s, debug:%s" % (
         args.host, args.port, args.ghost, args.gport, args.debug
     ))
-    wsgi.WSGIServer((args.host, int(args.port)), app).serve_forever()
+    try:
+        wsgi.WSGIServer((args.host, int(args.port)), app).serve_forever()
+    except KeyboardInterrupt:
+        sys.exit(0)
 
 
 if __name__ == '__main__':
