@@ -189,7 +189,7 @@ class CallBackMgr(object):
         return f
 
 
-class TcpServer(asyncore.dispatcher, CallBackMgr):
+class GourdTcp(asyncore.dispatcher, CallBackMgr):
     backlog = None
     terminator = None
     logger = None
@@ -290,7 +290,7 @@ class TcpRequestHandler(asynchat.async_chat):
         return self._json_data
 
 
-class UdpServer(asyncore.dispatcher, CallBackMgr):
+class GourdUdp(asyncore.dispatcher, CallBackMgr):
     _address = None
     _raw_data = None
     _json_data = None
